==> switchyard-common-0.4.0-20120322.030219-22-sources.jar: org/switchyard/common/io/pull/StringPuller.java <==
/* 
 * JBoss, Home of Professional Open Source 
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @author tags. All rights reserved. 
 * See the copyright.txt in the distribution for a 
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use, 
 * modify, copy, or redistribute it subject to the terms and conditions 
 * of the GNU Lesser General Public License, v. 2.1. 
 * This program is distributed in the hope that it will be useful, but WITHOUT A 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details. 
 * You should have received a copy of the GNU Lesser General Public License, 
 * v.2.1 along with this distribution; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
 * MA  02110-1301, USA.
 */

package org.switchyard.common.io.pull;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;


/**
 * Utility class to safely access ("pull") Strings from various sources.
 *
 * @author David Ward &lt;<a href="mailto:dward@jboss.org">dward@jboss.org</a>&gt; (C) 2011 Red Hat Inc.
 */
public class StringPuller extends Puller<String> {

    /**
     * {@inheritDoc}
     */
    @Override
    public String pull(InputStream is) throws IOException {
        return pull(new InputStreamReader(is));
    }

    /**
     * Safely pulls a String from a Reader.
     * @param reader a Reader of the resource
     * @return the resource, or null if not found
     * @throws IOException if a problem occurred
     */
    public String pull(Reader reader) throws IOException {
        StringBuffer buffer = new StringBuffer(1024);
        reader = new BufferedReader(reader);
        char[] c = new char[1024];
        int i = 0;
        while ((i = reader.read(c)) != -1) {
            buffer.append(c, 0, i);
        }
        return buffer.toString();
    }

}

==> switchyard-common-0.8.0-20130321.002826-23-sources.jar: org/switchyard/common/io/pull/StringPuller.java <==
/* 
 * JBoss, Home of Professional Open Source 
 * Copyright 2011 Red Hat Inc. and/or its affiliates and other contributors
 * as indicated by the @author tags. All rights reserved. 
 * See the copyright.txt in the distribution for a 
 * full listing of individual contributors.
 *
 * This copyrighted material is made available to anyone wishing to use, 
 * modify, copy, or redistribute it subject to the terms and conditions 
 * of the GNU Lesser General Public License, v. 2.1. 
 * This program is distributed in the hope that it will be useful, but WITHOUT A 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details. 
 * You should have received a copy of the GNU Lesser General Public License, 
 * v.2.1 along with this distribution; if not, write to the Free Software 
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
 * MA  02110-1301, USA.
 */

package org.switchyard.common.io.pull;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;

/**
 * Utility class to safely access ("pull") Strings from various sources.
 *
 * @author David Ward &lt;<a href="mailto:dward@jboss.org">dward@jboss.org</a>&gt; (C) 2011 Red Hat Inc.
 */
public class StringPuller extends Puller<String> {

    /**
     * {@inheritDoc}
     */
    @Override
    public String pull(InputStream stream) throws IOException {
        return pull(new InputStreamReader(stream));
    }

    /**
     * Safely pulls a String from a Reader.
     * @param reader a Reader of the resource
     * @return the resource, or null if not found
     * @throws IOException if a problem occurred
     */
    public String pull(Reader reader) throws IOException {
        StringBuffer buffer = new StringBuffer(1024);
        reader = new BufferedReader(reader);
        char[] c = new char[1024];
        int i = 0;
        while ((i = reader.read(c)) != -1) {
            buffer.append(c, 0, i);
        }
        return buffer.toString();
    }

}
